module.exports = defineTest({
	description: 'handles hoisted declarations in deeply nested switch statements'
});
